Name:		autojump
Version:	22.5.3
Release:	%mkrel 8
Summary:	A fast way to navigate your filesystem from the command line
Group:		Shells
License:	GPLv3+
URL:		https://github.com/wting/autojump
Source:		https://github.com/wting/autojump/archive/release-v%{version}/%{name}-%{version}.tar.gz
Patch0:		remove-homebrew-check.patch
Patch1:		install-add-distribution-arg.patch

BuildArch:	noarch
BuildRequires:	python3-devel
BuildRequires:	python3-mock
BuildRequires:	python3-pytest

%description
autojump provides a fast way to navigate your filesystem, with a "cd command
that learns".

It works by maintaining a database of the directories you use the most from
the command line, and allows you to "jump" to frequently used directories by
typing only "j" + a small pattern.

%package zsh
Requires:       %{name} = %{version}-%{release}
Group:          Shells
Summary:        Autojump for zsh

%description zsh
autojump is a faster way to navigate your filesystem. It works by maintaining
a database of the directories you use the most from the command line.
autojump-zsh is designed to work with zsh.

%prep
%autosetup -p1 -n %{name}-release-v%{version}

# Use system argparse
sed -i 's|autojump_argparse|argparse|' bin/%{name}

# Fix shebangs, non .py files need to be specified manually, so we provide bin/* as well as .
%py3_shebang_fix . ./bin/*
sed -i '1{/^#!/d}' bin/%{name}_*.py

%build
#make docs

%install
%{__python3} install.py \
  --destdir %{buildroot} \
  --prefix usr \
  --zshshare %{buildroot}%{_datadir}/zsh/site-functions \
  --distribution

# Do not need bundled modules
rm %{buildroot}%{_bindir}/%{name}_argparse.py

# Move modules to proper directory
mkdir -p %{buildroot}%{python3_sitelib}
mv %{buildroot}%{_bindir}/%{name}_*.py %{buildroot}%{python3_sitelib}/

%check
%{__python3} -m pytest tests -vv

%files
%doc LICENSE README.md AUTHORS
%{_bindir}/%{name}
%{python3_sitelib}/%{name}_data.py
%{python3_sitelib}/%{name}_match.py
%{python3_sitelib}/%{name}_utils.py
%{python3_sitelib}/__pycache__/%{name}*.pyc
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/icon.png
%{_mandir}/man1/%{name}.1*
%config(noreplace) %{_sysconfdir}/profile.d/%{name}.sh
%config(noreplace) %{_datadir}/%{name}/%{name}.bash
%config(noreplace) %{_datadir}/%{name}/%{name}.fish

%files zsh
%config(noreplace) %{_datadir}/%{name}/%{name}.zsh
%{_datadir}/zsh/site-functions/_j


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 22.5.3-8.mga10
+ Revision: 2238019
- Mageia 10 Mass Rebuild

* Sat Mar 01 2025 papoteur <papoteur> 22.5.3-7.mga10
+ Revision: 2154371
- rebuild for python3.13

* Thu Dec 21 2023 papoteur <papoteur> 22.5.3-6.mga10
+ Revision: 2020737
- Rebuild for python 3.12

* Sat Mar 26 2022 umeabot <umeabot> 22.5.3-5.mga9
+ Revision: 1828449
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 22.5.3-4.mga9
+ Revision: 1774970
- rebuild for python-3.10

* Sun Mar 21 2021 neoclust <neoclust> 22.5.3-3.mga9
+ Revision: 1706826
- Rebuild against python 3.9

* Wed Oct 21 2020 akien <akien> 22.5.3-2.mga8
+ Revision: 1637587
- Add Fedora patch to fix distro packaging

* Fri Feb 28 2020 daviddavid <daviddavid> 22.5.3-1.mga8
+ Revision: 1551683
- new version: 22.5.3
- switch to python3
- use system argparse
- run tests
- do not check for homebrew
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 21.7.1-6.mga7
+ Revision: 1260815
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 21.7.1-5.mga7
+ Revision: 1259965
- Mageia 7 Mass Rebuild

* Fri Feb 05 2016 umeabot <umeabot> 21.7.1-4.mga6
+ Revision: 939785
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 21.7.1-3.mga5
+ Revision: 746136
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 21.7.1-2.mga5
+ Revision: 678061
- Mageia 5 Mass Rebuild

* Tue Aug 12 2014 stormi <stormi> 21.7.1-1.mga5
+ Revision: 662055
- update autojump to 21.7.1
+ dams <dams>
- clean specfile

* Fri Oct 18 2013 umeabot <umeabot> 21.1.2-3.mga4
+ Revision: 502977
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 21.1.2-2.mga3
+ Revision: 346661
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 stormi <stormi> 21.1.2-1.mga3
+ Revision: 338371
- fix group
- new version 21.2.1
- new version 19

* Sat Sep 24 2011 stormi <stormi> 17-1.mga2
+ Revision: 147542
- add patch to remove the need for a "python2" binary
- new version 17
- clean spec

* Thu Apr 14 2011 stormi <stormi> 15-1.mga1
+ Revision: 85534
- imported package autojump

